From 6f0c448fc1c267cb176562fc50e5a2132ab59a59 Mon Sep 17 00:00:00 2001
From: Qingmin Liu <qingmin.liu@broadcom.com>
Date: Fri, 22 Nov 2019 17:31:17 +0800
Subject: [PATCH 1/2] bnxt: fix pcie_link_width compatible issue

For Centos 8, pcie_get_minimum_link is deprecated. Do not use this to
judge whether pcie_link_width is defined or not.
Introduce HAVE_PCIE_LINK_WIDTH to fix this.
---
 main/Cumulus/drivers/linux/v3/Makefile      | 4 ++++
 main/Cumulus/drivers/linux/v3/bnxt_compat.h | 3 +++
 2 files changed, 7 insertions(+)

diff --git a/main/Cumulus/drivers/linux/v3/Makefile b/main/Cumulus/drivers/linux/v3/Makefile
index 1771d5662..299ad9c45 100644
--- a/main/Cumulus/drivers/linux/v3/Makefile
+++ b/main/Cumulus/drivers/linux/v3/Makefile
@@ -543,6 +543,10 @@ ifneq ($(shell grep -o "pcie_get_minimum_link" $(LINUXSRC)/include/linux/pci.h),
   DISTRO_CFLAG += -DHAVE_PCIE_GET_MINIMUM_LINK
 endif
 
+ifneq ($(shell grep -o "pcie_link_width" $(LINUXSRC)/include/linux/pci.h),)
+  DISTRO_CFLAG += -DHAVE_PCIE_LINK_WIDTH
+endif
+
 ifneq ($(shell grep -o "pcie_capability_read_word" $(LINUXSRC)/include/linux/pci.h),)
   DISTRO_CFLAG += -DHAVE_PCIE_CAPABILITY_READ_WORD
 endif
diff --git a/main/Cumulus/drivers/linux/v3/bnxt_compat.h b/main/Cumulus/drivers/linux/v3/bnxt_compat.h
index 739f63157..deb8c508b 100644
--- a/main/Cumulus/drivers/linux/v3/bnxt_compat.h
+++ b/main/Cumulus/drivers/linux/v3/bnxt_compat.h
@@ -786,9 +786,12 @@ static inline void *vzalloc(size_t size)
 #endif
 
 #ifndef HAVE_PCIE_GET_MINIMUM_LINK
+
+#ifndef HAVE_PCIE_LINK_WIDTH
 enum pcie_link_width {
 	PCIE_LNK_WIDTH_UNKNOWN		= 0xFF,
 };
+#endif
 
 #ifndef HAVE_PCIE_BUS_SPEED
 enum pci_bus_speed {
-- 
2.21.0

